package cn.iocoder.yudao.module.museums.controller.admin.specimeninfo.vo;

import io.swagger.v3.oas.annotations.media.Schema;
import lombok.*;

import java.time.LocalDate;
import java.util.*;
import javax.validation.constraints.*;
import java.math.BigDecimal;
import org.springframework.format.annotation.DateTimeFormat;
import java.time.LocalDateTime;

@Schema(description = "管理后台 - 标本管理新增/修改 Request VO")
@Data
public class SpecimenInfoSaveReqVO {

    @Schema(description = "主键", requiredMode = Schema.RequiredMode.REQUIRED, example = "1")
    private Integer id;

    @Schema(description = "标本类型（矿物、岩石矿石、化石、陨石）", requiredMode = Schema.RequiredMode.REQUIRED, example = "1")
    @NotNull(message = "标本类型（矿物、岩石矿石、化石、陨石）不能为空")
    private Integer specimenType;

    @Schema(description = "标本编号", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotEmpty(message = "标本编号不能为空")
    private String specimenNumber;

    @Schema(description = "资产号")
    private String assetNumber;

    @Schema(description = "存放位置")
    private String storageLocation;

    @Schema(description = "中文名称", example = "赵六")
    private String chineseName;

    @Schema(description = "英文名称", example = "Maven")
    private String englishName;

    @Schema(description = "成分")
    private String composition;

    @Schema(description = "产地")
    private String origin;

    @Schema(description = "时代")
    private String era;

    @Schema(description = "保存地层")
    private String preservedLayer;

    @Schema(description = "陨石类型", example = "2")
    private String meteoriteType;

    @Schema(description = "国际命名", example = "王五")
    private String internationalName;

    @Schema(description = "发现时间")
    private LocalDate discoveryTime;

    @Schema(description = "降落时间")
    private LocalDate fallTime;

    @Schema(description = "保存类型（标本、光片、薄片模型及其他）", example = "1")
    private Integer preservationType;

    @Schema(description = "尺寸")
    private String size;

    @Schema(description = "重量")
    private BigDecimal weight;

    @Schema(description = "来源（采购、捐赠、采集）")
    private Integer source;

    @Schema(description = "标本提供者（供应商、捐赠人、采集人）")
    private String provider;

    @Schema(description = "入藏时间（购买、捐赠、采集时间）")
    private LocalDate acquisitionTime;

    @Schema(description = "用途")
    private String purpose;

    @Schema(description = "描述", example = "黑红色陨石")
    private String description;

    @Schema(description = "馆藏状态（在馆、借出）", example = "2")
    private Integer collectionStatus;

    @Schema(description = "备注")
    private String notes;

    @Schema(description = "图片名称", example = "芋艿")
    private String imageName;

    @Schema(description = "图片路径")
    private String imagePath;

    @Schema(description = "注销原因", example = "不香")
    private String deletedReason;

    @Schema(description = "入库操作员")
    private String operator;

    @Schema(description = "入库时间")
    private LocalDateTime entryDate;

}