package cn.iocoder.yudao.module.museums.service.museumsdocument;

import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;
import cn.iocoder.yudao.module.museums.controller.admin.museumsdocument.vo.*;
import cn.iocoder.yudao.module.museums.dal.dataobject.museumsdocument.MuseumsDocumentDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;

import cn.iocoder.yudao.module.museums.dal.mysql.museumsdocument.MuseumsDocumentMapper;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.museums.enums.ErrorCodeConstants.*;

/**
 * 博物馆文件管理 Service 实现类
 *
 * @author 芋道源码
 */
@Service
@Validated
public class MuseumsDocumentServiceImpl implements MuseumsDocumentService {

    @Resource
    private MuseumsDocumentMapper documentMapper;

    @Override
    public Integer createDocument(MuseumsDocumentSaveReqVO createReqVO) {
        // 插入
        MuseumsDocumentDO document = BeanUtils.toBean(createReqVO, MuseumsDocumentDO.class);
        documentMapper.insert(document);
        // 返回
        return document.getId();
    }

    @Override
    public void updateDocument(MuseumsDocumentSaveReqVO updateReqVO) {
        // 校验存在
        validateDocumentExists(updateReqVO.getId());
        // 更新
        MuseumsDocumentDO updateObj = BeanUtils.toBean(updateReqVO, MuseumsDocumentDO.class);
        documentMapper.updateById(updateObj);
    }

    @Override
    public void deleteDocument(Integer id) {
        // 校验存在
        validateDocumentExists(id);
        // 删除
        documentMapper.deleteById(id);
    }

    private void validateDocumentExists(Integer id) {
        if (documentMapper.selectById(id) == null) {
            throw exception(DOCUMENT_NOT_EXISTS);
        }
    }

    @Override
    public MuseumsDocumentDO getDocument(Integer id) {
        return documentMapper.selectById(id);
    }

    @Override
    public PageResult<MuseumsDocumentDO> getDocumentPage(MuseumsDocumentPageReqVO pageReqVO) {
        return documentMapper.selectPage(pageReqVO);
    }

}