package cn.iocoder.yudao.module.museums.service.photogroup;

import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;
import cn.iocoder.yudao.module.museums.controller.admin.photogroup.vo.*;
import cn.iocoder.yudao.module.museums.dal.dataobject.photogroup.PhotoGroupDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;

import cn.iocoder.yudao.module.museums.dal.mysql.photogroup.PhotoGroupMapper;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.museums.enums.ErrorCodeConstants.*;

/**
 * 博物馆照片组 Service 实现类
 *
 * @author qpw
 */
@Service
@Validated
public class PhotoGroupServiceImpl implements PhotoGroupService {

    @Resource
    private PhotoGroupMapper photoGroupMapper;

    @Override
    public Integer createPhotoGroup(PhotoGroupSaveReqVO createReqVO) {
        // 插入
        PhotoGroupDO photoGroup = BeanUtils.toBean(createReqVO, PhotoGroupDO.class);
        photoGroupMapper.insert(photoGroup);
        // 返回
        return photoGroup.getId();
    }

    @Override
    public void updatePhotoGroup(PhotoGroupSaveReqVO updateReqVO) {
        // 校验存在
        validatePhotoGroupExists(updateReqVO.getId());
        // 更新
        PhotoGroupDO updateObj = BeanUtils.toBean(updateReqVO, PhotoGroupDO.class);
        photoGroupMapper.updateById(updateObj);
    }

    @Override
    public void deletePhotoGroup(Integer id) {
        // 校验存在
        validatePhotoGroupExists(id);
        // 删除
        photoGroupMapper.deleteById(id);
    }

    private void validatePhotoGroupExists(Integer id) {
        if (photoGroupMapper.selectById(id) == null) {
            throw exception(PHOTO_GROUP_NOT_EXISTS);
        }
    }

    @Override
    public PhotoGroupDO getPhotoGroup(Integer id) {
        return photoGroupMapper.selectById(id);
    }

    @Override
    public PageResult<PhotoGroupDO> getPhotoGroupPage(PhotoGroupPageReqVO pageReqVO) {
        return photoGroupMapper.selectPage(pageReqVO);
    }

}