package cn.iocoder.yudao.module.museums.service.photos;

import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;
import cn.iocoder.yudao.module.museums.controller.admin.photos.vo.*;
import cn.iocoder.yudao.module.museums.dal.dataobject.photos.PhotosDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;

import cn.iocoder.yudao.module.museums.dal.mysql.photos.PhotosMapper;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.museums.enums.ErrorCodeConstants.*;

/**
 * 博物馆照片 Service 实现类
 *
 * @author qpw
 */
@Service
@Validated
public class PhotosServiceImpl implements PhotosService {

    @Resource
    private PhotosMapper photosMapper;

    @Override
    public Integer createPhotos(PhotosSaveReqVO createReqVO) {
        // 插入
        PhotosDO photos = BeanUtils.toBean(createReqVO, PhotosDO.class);
        photosMapper.insert(photos);
        // 返回
        return photos.getId();
    }

    @Override
    public void updatePhotos(PhotosSaveReqVO updateReqVO) {
        // 校验存在
        validatePhotosExists(updateReqVO.getId());
        // 更新
        PhotosDO updateObj = BeanUtils.toBean(updateReqVO, PhotosDO.class);
        photosMapper.updateById(updateObj);
    }

    @Override
    public void deletePhotos(Integer id) {
        // 校验存在
        validatePhotosExists(id);
        // 删除
        photosMapper.deleteById(id);
    }

    private void validatePhotosExists(Integer id) {
        if (photosMapper.selectById(id) == null) {
            throw exception(PHOTOS_NOT_EXISTS);
        }
    }

    @Override
    public PhotosDO getPhotos(Integer id) {
        return photosMapper.selectById(id);
    }

    @Override
    public PageResult<PhotosDO> getPhotosPage(PhotosPageReqVO pageReqVO) {
        return photosMapper.selectPage(pageReqVO);
    }

}