package cn.iocoder.yudao.module.museums.service.specimeninfo;

import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;
import cn.iocoder.yudao.module.museums.controller.admin.specimeninfo.vo.*;
import cn.iocoder.yudao.module.museums.dal.dataobject.specimeninfo.SpecimenInfoDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;

import cn.iocoder.yudao.module.museums.dal.mysql.specimeninfo.SpecimenInfoMapper;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.museums.enums.ErrorCodeConstants.*;
/**
 * 标本管理 Service 实现类
 *
 * @author 普伟
 */
@Service
@Validated
public class SpecimenInfoServiceImpl implements SpecimenInfoService {

    @Resource
    private SpecimenInfoMapper specimenInfoMapper;

    @Override
    public Integer createSpecimenInfo(SpecimenInfoSaveReqVO createReqVO) {
        // 插入
        SpecimenInfoDO specimenInfo = BeanUtils.toBean(createReqVO, SpecimenInfoDO.class);
        specimenInfoMapper.insert(specimenInfo);
        // 返回
        return specimenInfo.getId();
    }

    @Override
    public void updateSpecimenInfo(SpecimenInfoSaveReqVO updateReqVO) {
        // 校验存在
        validateSpecimenInfoExists(updateReqVO.getId());
        // 更新
        SpecimenInfoDO updateObj = BeanUtils.toBean(updateReqVO, SpecimenInfoDO.class);
        specimenInfoMapper.updateById(updateObj);
    }

    @Override
    public void deleteSpecimenInfo(Integer id) {
        // 校验存在
        validateSpecimenInfoExists(id);
        // 删除
        specimenInfoMapper.deleteById(id);
    }

    private void validateSpecimenInfoExists(Integer id) {
        if (specimenInfoMapper.selectById(id) == null) {
            throw exception(SPECIMEN_INFO_NOT_EXISTS);
        }
    }

    @Override
    public SpecimenInfoDO getSpecimenInfo(Integer id) {
        return specimenInfoMapper.selectById(id);
    }

    @Override
    public PageResult<SpecimenInfoDO> getSpecimenInfoPage(SpecimenInfoPageReqVO pageReqVO) {
        return specimenInfoMapper.selectPage(pageReqVO);
    }

}