package cn.iocoder.yudao.module.museums.service.photogroup;

import org.junit.jupiter.api.Disabled;
import org.junit.jupiter.api.Test;
import org.springframework.boot.test.mock.mockito.MockBean;

import javax.annotation.Resource;

import cn.iocoder.yudao.framework.test.core.ut.BaseDbUnitTest;

import cn.iocoder.yudao.module.museums.controller.admin.photogroup.vo.*;
import cn.iocoder.yudao.module.museums.dal.dataobject.photogroup.PhotoGroupDO;
import cn.iocoder.yudao.module.museums.dal.mysql.photogroup.PhotoGroupMapper;
import cn.iocoder.yudao.framework.common.pojo.PageResult;

import javax.annotation.Resource;
import org.springframework.context.annotation.Import;
import java.util.*;
import java.time.LocalDateTime;

import static cn.hutool.core.util.RandomUtil.*;
import static cn.iocoder.yudao.module.museums.enums.ErrorCodeConstants.*;
import static cn.iocoder.yudao.framework.test.core.util.AssertUtils.*;
import static cn.iocoder.yudao.framework.test.core.util.RandomUtils.*;
import static cn.iocoder.yudao.framework.common.util.date.LocalDateTimeUtils.*;
import static cn.iocoder.yudao.framework.common.util.object.ObjectUtils.*;
import static cn.iocoder.yudao.framework.common.util.date.DateUtils.*;
import static org.junit.jupiter.api.Assertions.*;
import static org.mockito.Mockito.*;

/**
 * {@link PhotoGroupServiceImpl} 的单元测试类
 *
 * @author qpw
 */
@Import(PhotoGroupServiceImpl.class)
public class PhotoGroupServiceImplTest extends BaseDbUnitTest {

    @Resource
    private PhotoGroupServiceImpl photoGroupService;

    @Resource
    private PhotoGroupMapper photoGroupMapper;

    @Test
    public void testCreatePhotoGroup_success() {
        // 准备参数
        PhotoGroupSaveReqVO createReqVO = randomPojo(PhotoGroupSaveReqVO.class).setId(null);

        // 调用
        Integer photoGroupId = photoGroupService.createPhotoGroup(createReqVO);
        // 断言
        assertNotNull(photoGroupId);
        // 校验记录的属性是否正确
        PhotoGroupDO photoGroup = photoGroupMapper.selectById(photoGroupId);
        assertPojoEquals(createReqVO, photoGroup, "id");
    }

    @Test
    public void testUpdatePhotoGroup_success() {
        // mock 数据
        PhotoGroupDO dbPhotoGroup = randomPojo(PhotoGroupDO.class);
        photoGroupMapper.insert(dbPhotoGroup);// @Sql: 先插入出一条存在的数据
        // 准备参数
        PhotoGroupSaveReqVO updateReqVO = randomPojo(PhotoGroupSaveReqVO.class, o -> {
            o.setId(dbPhotoGroup.getId()); // 设置更新的 ID
        });

        // 调用
        photoGroupService.updatePhotoGroup(updateReqVO);
        // 校验是否更新正确
        PhotoGroupDO photoGroup = photoGroupMapper.selectById(updateReqVO.getId()); // 获取最新的
        assertPojoEquals(updateReqVO, photoGroup);
    }

    @Test
    public void testUpdatePhotoGroup_notExists() {
        // 准备参数
        PhotoGroupSaveReqVO updateReqVO = randomPojo(PhotoGroupSaveReqVO.class);

        // 调用, 并断言异常
        assertServiceException(() -> photoGroupService.updatePhotoGroup(updateReqVO), PHOTO_GROUP_NOT_EXISTS);
    }

    @Test
    public void testDeletePhotoGroup_success() {
        // mock 数据
        PhotoGroupDO dbPhotoGroup = randomPojo(PhotoGroupDO.class);
        photoGroupMapper.insert(dbPhotoGroup);// @Sql: 先插入出一条存在的数据
        // 准备参数
        Integer id = dbPhotoGroup.getId();

        // 调用
        photoGroupService.deletePhotoGroup(id);
       // 校验数据不存在了
       assertNull(photoGroupMapper.selectById(id));
    }

    @Test
    public void testDeletePhotoGroup_notExists() {
        // 准备参数
        Integer id = randomIntegerId();

        // 调用, 并断言异常
        assertServiceException(() -> photoGroupService.deletePhotoGroup(id), PHOTO_GROUP_NOT_EXISTS);
    }

    @Test
    @Disabled  // TODO 请修改 null 为需要的值，然后删除 @Disabled 注解
    public void testGetPhotoGroupPage() {
       // mock 数据
       PhotoGroupDO dbPhotoGroup = randomPojo(PhotoGroupDO.class, o -> { // 等会查询到
           o.setGroupName(null);
           o.setGroupDate(null);
           o.setGroupDescription(null);
           o.setCreatedAt(null);
           o.setCreateTime(null);
           o.setUploadPhotos(null);
       });
       photoGroupMapper.insert(dbPhotoGroup);
       // 测试 groupName 不匹配
       photoGroupMapper.insert(cloneIgnoreId(dbPhotoGroup, o -> o.setGroupName(null)));
       // 测试 groupDate 不匹配
       photoGroupMapper.insert(cloneIgnoreId(dbPhotoGroup, o -> o.setGroupDate(null)));
       // 测试 groupDescription 不匹配
       photoGroupMapper.insert(cloneIgnoreId(dbPhotoGroup, o -> o.setGroupDescription(null)));
       // 测试 createdAt 不匹配
       photoGroupMapper.insert(cloneIgnoreId(dbPhotoGroup, o -> o.setCreatedAt(null)));
       // 测试 createTime 不匹配
       photoGroupMapper.insert(cloneIgnoreId(dbPhotoGroup, o -> o.setCreateTime(null)));
       // 测试 uploadPhotos 不匹配
       photoGroupMapper.insert(cloneIgnoreId(dbPhotoGroup, o -> o.setUploadPhotos(null)));
       // 准备参数
       PhotoGroupPageReqVO reqVO = new PhotoGroupPageReqVO();
       reqVO.setGroupName(null);
       reqVO.setGroupDate(buildBetweenTime(2023, 2, 1, 2023, 2, 28));
       reqVO.setGroupDescription(null);
       reqVO.setCreatedAt(null);
       reqVO.setCreateTime(buildBetweenTime(2023, 2, 1, 2023, 2, 28));
       reqVO.setUploadPhotos(null);

       // 调用
       PageResult<PhotoGroupDO> pageResult = photoGroupService.getPhotoGroupPage(reqVO);
       // 断言
       assertEquals(1, pageResult.getTotal());
       assertEquals(1, pageResult.getList().size());
       assertPojoEquals(dbPhotoGroup, pageResult.getList().get(0));
    }

}