package cn.iocoder.yudao.module.museums.service.photos;

import org.junit.jupiter.api.Disabled;
import org.junit.jupiter.api.Test;
import org.springframework.boot.test.mock.mockito.MockBean;

import javax.annotation.Resource;

import cn.iocoder.yudao.framework.test.core.ut.BaseDbUnitTest;

import cn.iocoder.yudao.module.museums.controller.admin.photos.vo.*;
import cn.iocoder.yudao.module.museums.dal.dataobject.photos.PhotosDO;
import cn.iocoder.yudao.module.museums.dal.mysql.photos.PhotosMapper;
import cn.iocoder.yudao.framework.common.pojo.PageResult;

import javax.annotation.Resource;
import org.springframework.context.annotation.Import;
import java.util.*;
import java.time.LocalDateTime;

import static cn.hutool.core.util.RandomUtil.*;
import static cn.iocoder.yudao.module.museums.enums.ErrorCodeConstants.*;
import static cn.iocoder.yudao.framework.test.core.util.AssertUtils.*;
import static cn.iocoder.yudao.framework.test.core.util.RandomUtils.*;
import static cn.iocoder.yudao.framework.common.util.date.LocalDateTimeUtils.*;
import static cn.iocoder.yudao.framework.common.util.object.ObjectUtils.*;
import static cn.iocoder.yudao.framework.common.util.date.DateUtils.*;
import static org.junit.jupiter.api.Assertions.*;
import static org.mockito.Mockito.*;

/**
 * {@link PhotosServiceImpl} 的单元测试类
 *
 * @author qpw
 */
@Import(PhotosServiceImpl.class)
public class PhotosServiceImplTest extends BaseDbUnitTest {

    @Resource
    private PhotosServiceImpl photosService;

    @Resource
    private PhotosMapper photosMapper;

    @Test
    public void testCreatePhotos_success() {
        // 准备参数
        PhotosSaveReqVO createReqVO = randomPojo(PhotosSaveReqVO.class).setId(null);

        // 调用
        Integer photosId = photosService.createPhotos(createReqVO);
        // 断言
        assertNotNull(photosId);
        // 校验记录的属性是否正确
        PhotosDO photos = photosMapper.selectById(photosId);
        assertPojoEquals(createReqVO, photos, "id");
    }

    @Test
    public void testUpdatePhotos_success() {
        // mock 数据
        PhotosDO dbPhotos = randomPojo(PhotosDO.class);
        photosMapper.insert(dbPhotos);// @Sql: 先插入出一条存在的数据
        // 准备参数
        PhotosSaveReqVO updateReqVO = randomPojo(PhotosSaveReqVO.class, o -> {
            o.setId(dbPhotos.getId()); // 设置更新的 ID
        });

        // 调用
        photosService.updatePhotos(updateReqVO);
        // 校验是否更新正确
        PhotosDO photos = photosMapper.selectById(updateReqVO.getId()); // 获取最新的
        assertPojoEquals(updateReqVO, photos);
    }

    @Test
    public void testUpdatePhotos_notExists() {
        // 准备参数
        PhotosSaveReqVO updateReqVO = randomPojo(PhotosSaveReqVO.class);

        // 调用, 并断言异常
        assertServiceException(() -> photosService.updatePhotos(updateReqVO), PHOTOS_NOT_EXISTS);
    }

    @Test
    public void testDeletePhotos_success() {
        // mock 数据
        PhotosDO dbPhotos = randomPojo(PhotosDO.class);
        photosMapper.insert(dbPhotos);// @Sql: 先插入出一条存在的数据
        // 准备参数
        Integer id = dbPhotos.getId();

        // 调用
        photosService.deletePhotos(id);
       // 校验数据不存在了
       assertNull(photosMapper.selectById(id));
    }

    @Test
    public void testDeletePhotos_notExists() {
        // 准备参数
        Integer id = randomIntegerId();

        // 调用, 并断言异常
        assertServiceException(() -> photosService.deletePhotos(id), PHOTOS_NOT_EXISTS);
    }

    @Test
    @Disabled  // TODO 请修改 null 为需要的值，然后删除 @Disabled 注解
    public void testGetPhotosPage() {
       // mock 数据
       PhotosDO dbPhotos = randomPojo(PhotosDO.class, o -> { // 等会查询到
           o.setGroupId(null);
           o.setPhotoUrl(null);
           o.setCreatedAt(null);
           o.setCreateTime(null);
       });
       photosMapper.insert(dbPhotos);
       // 测试 groupId 不匹配
       photosMapper.insert(cloneIgnoreId(dbPhotos, o -> o.setGroupId(null)));
       // 测试 photoUrl 不匹配
       photosMapper.insert(cloneIgnoreId(dbPhotos, o -> o.setPhotoUrl(null)));
       // 测试 createdAt 不匹配
       photosMapper.insert(cloneIgnoreId(dbPhotos, o -> o.setCreatedAt(null)));
       // 测试 createTime 不匹配
       photosMapper.insert(cloneIgnoreId(dbPhotos, o -> o.setCreateTime(null)));
       // 准备参数
       PhotosPageReqVO reqVO = new PhotosPageReqVO();
       reqVO.setGroupId(null);
       reqVO.setPhotoUrl(null);
       reqVO.setCreatedAt(null);
       reqVO.setCreateTime(buildBetweenTime(2023, 2, 1, 2023, 2, 28));

       // 调用
       PageResult<PhotosDO> pageResult = photosService.getPhotosPage(reqVO);
       // 断言
       assertEquals(1, pageResult.getTotal());
       assertEquals(1, pageResult.getList().size());
       assertPojoEquals(dbPhotos, pageResult.getList().get(0));
    }

}